#[non_exhaustive]pub struct CreateMultiplexInput {
pub availability_zones: Option<Vec<String>>,
pub multiplex_settings: Option<MultiplexSettings>,
pub name: Option<String>,
pub request_id: Option<String>,
pub tags: Option<HashMap<String, String>>,
}Expand description
A request to create a multiplex.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.availability_zones: Option<Vec<String>>A list of availability zones for the multiplex. You must specify exactly two.
multiplex_settings: Option<MultiplexSettings>Configuration for a multiplex event.
name: Option<String>Name of multiplex.
request_id: Option<String>Unique request ID. This prevents retries from creating multiple resources.
A collection of key-value pairs.
Implementations
Sourceimpl CreateMultiplexInput
impl CreateMultiplexInput
Sourcepub fn availability_zones(&self) -> &[String]
pub fn availability_zones(&self) -> &[String]
A list of availability zones for the multiplex. You must specify exactly two.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .availability_zones.is_none().
Sourcepub fn multiplex_settings(&self) -> Option<&MultiplexSettings>
pub fn multiplex_settings(&self) -> Option<&MultiplexSettings>
Configuration for a multiplex event.
Sourcepub fn request_id(&self) -> Option<&str>
pub fn request_id(&self) -> Option<&str>
Unique request ID. This prevents retries from creating multiple resources.
A collection of key-value pairs.
Sourceimpl CreateMultiplexInput
impl CreateMultiplexInput
Sourcepub fn builder() -> CreateMultiplexInputBuilder
pub fn builder() -> CreateMultiplexInputBuilder
Creates a new builder-style object to manufacture CreateMultiplexInput.