#[non_exhaustive]pub struct CreateNetworkInput {
pub ip_pools: Option<Vec<IpPoolCreateRequest>>,
pub name: Option<String>,
pub request_id: Option<String>,
pub routes: Option<Vec<RouteCreateRequest>>,
pub tags: Option<HashMap<String, String>>,
}Expand description
A request to create a Network.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.ip_pools: Option<Vec<IpPoolCreateRequest>>An array of IpPoolCreateRequests that identify a collection of IP addresses in your network that you want to reserve for use in MediaLive Anywhere. MediaLiveAnywhere uses these IP addresses for Push inputs (in both Bridge and NATnetworks) and for output destinations (only in Bridge networks). EachIpPoolUpdateRequest specifies one CIDR block.
name: Option<String>Specify a name that is unique in the AWS account. We recommend that you assign a name that hints at the type of traffic on the network. Names are case-sensitive.
request_id: Option<String>An ID that you assign to a create request. This ID ensures idempotency when creating resources.
routes: Option<Vec<RouteCreateRequest>>An array of routes that MediaLive Anywhere needs to know about in order to route encoding traffic.
A collection of key-value pairs.
Implementations
Sourceimpl CreateNetworkInput
impl CreateNetworkInput
Sourcepub fn ip_pools(&self) -> &[IpPoolCreateRequest]
pub fn ip_pools(&self) -> &[IpPoolCreateRequest]
An array of IpPoolCreateRequests that identify a collection of IP addresses in your network that you want to reserve for use in MediaLive Anywhere. MediaLiveAnywhere uses these IP addresses for Push inputs (in both Bridge and NATnetworks) and for output destinations (only in Bridge networks). EachIpPoolUpdateRequest specifies one CIDR block.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .ip_pools.is_none().
Sourcepub fn name(&self) -> Option<&str>
pub fn name(&self) -> Option<&str>
Specify a name that is unique in the AWS account. We recommend that you assign a name that hints at the type of traffic on the network. Names are case-sensitive.
Sourcepub fn request_id(&self) -> Option<&str>
pub fn request_id(&self) -> Option<&str>
An ID that you assign to a create request. This ID ensures idempotency when creating resources.
Sourcepub fn routes(&self) -> &[RouteCreateRequest]
pub fn routes(&self) -> &[RouteCreateRequest]
An array of routes that MediaLive Anywhere needs to know about in order to route encoding traffic.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .routes.is_none().
A collection of key-value pairs.
Sourceimpl CreateNetworkInput
impl CreateNetworkInput
Sourcepub fn builder() -> CreateNetworkInputBuilder
pub fn builder() -> CreateNetworkInputBuilder
Creates a new builder-style object to manufacture CreateNetworkInput.