#[non_exhaustive]pub struct ListMultiplexProgramsInput {
pub max_results: Option<i32>,
pub multiplex_id: Option<String>,
pub next_token: Option<String>,
}Expand description
Placeholder documentation for ListMultiplexProgramsRequest
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.max_results: Option<i32>The maximum number of items to return.
multiplex_id: Option<String>The ID of the multiplex that the programs belong to.
next_token: Option<String>The token to retrieve the next page of results.
Implementations
Sourceimpl ListMultiplexProgramsInput
impl ListMultiplexProgramsInput
Sourcepub fn max_results(&self) -> Option<i32>
pub fn max_results(&self) -> Option<i32>
The maximum number of items to return.
Sourcepub fn multiplex_id(&self) -> Option<&str>
pub fn multiplex_id(&self) -> Option<&str>
The ID of the multiplex that the programs belong to.
Sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
The token to retrieve the next page of results.
Sourceimpl ListMultiplexProgramsInput
impl ListMultiplexProgramsInput
Sourcepub fn builder() -> ListMultiplexProgramsInputBuilder
pub fn builder() -> ListMultiplexProgramsInputBuilder
Creates a new builder-style object to manufacture ListMultiplexProgramsInput.