#[non_exhaustive]pub struct AudioNormalizationSettings {
pub algorithm: Option<AudioNormalizationAlgorithm>,
pub algorithm_control: Option<AudioNormalizationAlgorithmControl>,
pub target_lkfs: Option<f64>,
}Expand description
Audio Normalization Settings
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.algorithm: Option<AudioNormalizationAlgorithm>Audio normalization algorithm to use. itu17701 conforms to the CALM Act specification, itu17702 conforms to the EBU R-128 specification.
algorithm_control: Option<AudioNormalizationAlgorithmControl>When set to correctAudio the output audio is corrected using the chosen algorithm. If set to measureOnly, the audio will be measured but not adjusted.
target_lkfs: Option<f64>Target LKFS(loudness) to adjust volume to. If no value is entered, a default value will be used according to the chosen algorithm. The CALM Act recommends a target of -24 LKFS. The EBU R-128 specification recommends a target of -23 LKFS.
Implementations
Sourceimpl AudioNormalizationSettings
impl AudioNormalizationSettings
Sourcepub fn algorithm(&self) -> Option<&AudioNormalizationAlgorithm>
pub fn algorithm(&self) -> Option<&AudioNormalizationAlgorithm>
Audio normalization algorithm to use. itu17701 conforms to the CALM Act specification, itu17702 conforms to the EBU R-128 specification.
Sourcepub fn algorithm_control(&self) -> Option<&AudioNormalizationAlgorithmControl>
pub fn algorithm_control(&self) -> Option<&AudioNormalizationAlgorithmControl>
When set to correctAudio the output audio is corrected using the chosen algorithm. If set to measureOnly, the audio will be measured but not adjusted.
Sourcepub fn target_lkfs(&self) -> Option<f64>
pub fn target_lkfs(&self) -> Option<f64>
Target LKFS(loudness) to adjust volume to. If no value is entered, a default value will be used according to the chosen algorithm. The CALM Act recommends a target of -24 LKFS. The EBU R-128 specification recommends a target of -23 LKFS.
Sourceimpl AudioNormalizationSettings
impl AudioNormalizationSettings
Sourcepub fn builder() -> AudioNormalizationSettingsBuilder
pub fn builder() -> AudioNormalizationSettingsBuilder
Creates a new builder-style object to manufacture AudioNormalizationSettings.