#[non_exhaustive]pub struct MulticastSourceUpdateRequest {
pub source_ip: Option<String>,
pub url: Option<String>,
}Expand description
Pair of multicast url and source ip address (optional) that make up a multicast source.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.source_ip: Option<String>This represents the ip address of the device sending the multicast stream.
url: Option<String>This represents the customer’s source URL where multicast stream is pulled from.
Implementations
Sourceimpl MulticastSourceUpdateRequest
impl MulticastSourceUpdateRequest
Sourcepub fn builder() -> MulticastSourceUpdateRequestBuilder
pub fn builder() -> MulticastSourceUpdateRequestBuilder
Creates a new builder-style object to manufacture MulticastSourceUpdateRequest.